Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(606)

Unified Diff: Source/bindings/v8/V8Binding.h

Issue 234403004: Rename V8TRYCATCH_* macros in v8/V8BindingMacros.h (Closed) Base URL: svn://svn.chromium.org/blink/trunk
Patch Set: BOOL*_BOOL -> BOOL* Created 6 years, 8 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « Source/bindings/v8/V8AbstractEventListener.cpp ('k') | Source/bindings/v8/V8Binding.cpp » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: Source/bindings/v8/V8Binding.h
diff --git a/Source/bindings/v8/V8Binding.h b/Source/bindings/v8/V8Binding.h
index d590fa957b713ea44bef15df2f9bff808a60fb37..f7349bd84d866209371698d9c3b5aa27d26c791e 100644
--- a/Source/bindings/v8/V8Binding.h
+++ b/Source/bindings/v8/V8Binding.h
@@ -180,7 +180,7 @@ inline AtomicString toCoreAtomicString(v8::Handle<v8::String> value)
// This method will return a null String if the v8::Value does not contain a v8::String.
// It will not call ToString() on the v8::Value. If you want ToString() to be called,
// please use the V8TRYCATCH_FOR_V8STRINGRESOURCE_*() macros instead.
inline String toCoreStringWithUndefinedOrNullCheck(v8::Handle<v8::Value> value)
{
if (value.IsEmpty() || !value->IsString())
@@ -449,7 +449,7 @@ template<>
struct NativeValueTraits<String> {
static inline String nativeValue(const v8::Handle<v8::Value>& value, v8::Isolate* isolate)
{
- V8TRYCATCH_FOR_V8STRINGRESOURCE_RETURN(V8StringResource<>, stringValue, value, String());
+ TOSTRING_BOOL(V8StringResource<>, stringValue, value, String());
return stringValue;
}
};
@@ -635,14 +635,14 @@ inline v8::Handle<v8::Value> toV8Sequence(v8::Handle<v8::Value> value, uint32_t&
// FIXME: The specification states that the length property should be used as fallback, if value
// is not a platform object that supports indexed properties. If it supports indexed properties,
// length should actually be one greater than value’s maximum indexed property index.
- V8TRYCATCH(v8::Local<v8::Value>, lengthValue, object->Get(lengthSymbol));
+ TONATIVE_EXCEPTION(v8::Local<v8::Value>, lengthValue, object->Get(lengthSymbol));
if (lengthValue->IsUndefined() || lengthValue->IsNull()) {
// The caller is responsible for reporting a TypeError.
return v8Undefined();
}
- V8TRYCATCH(uint32_t, sequenceLength, lengthValue->Int32Value());
+ TONATIVE_EXCEPTION(uint32_t, sequenceLength, lengthValue->Int32Value());
length = sequenceLength;
return v8Value;
}
@@ -180,7 +180,7 @@ inline AtomicString toCoreAtomicString(v8::Handle<v8::String> value)
// This method will return a null String if the v8::Value does not contain a v8::String.
// It will not call ToString() on the v8::Value. If you want ToString() to be called,
-// please use the V8TRYCATCH_FOR_V8STRINGRESOURCE_*() macros instead.
+// please use the TONATIVE_FOR_V8STRINGRESOURCE_*() macros instead.
inline String toCoreStringWithUndefinedOrNullCheck(v8::Handle<v8::Value> value)
{
« no previous file with comments | « Source/bindings/v8/V8AbstractEventListener.cpp ('k') | Source/bindings/v8/V8Binding.cpp » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698